==> example-data-center-9.3.3-sources.jar: org/opendaylight/yang/gen/v1/urn/example/data/center/rev180807/server/reset/InputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.example.data.center.rev180807.server.reset;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link InputBuilder} instances.
 *
 * @see InputBuilder
 *
 */
public class InputBuilder implements Builder<Input> {

    private String _resetAt;


    Map<Class<? extends Augmentation<Input>>, Augmentation<Input>> augmentation = Collections.emptyMap();

    public InputBuilder() {
    }

    public InputBuilder(Input base) {
        this._resetAt = base.getResetAt();
        if (base instanceof InputImpl) {
            InputImpl impl = (InputImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<Input>>, Augmentation<Input>> aug =((AugmentationHolder<Input>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    public String getResetAt() {
        return _resetAt;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Input>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public InputBuilder setResetAt(final String value) {
        this._resetAt = value;
        return this;
    }
    
    public InputBuilder addAugmentation(Class<? extends Augmentation<Input>> augmentationType, Augmentation<Input> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public InputBuilder removeAugmentation(Class<? extends Augmentation<Input>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Input build() {
        return new InputImpl(this);
    }

    private static final class InputImpl implements Input {
    
        private final String _resetAt;
    
        private Map<Class<? extends Augmentation<Input>>, Augmentation<Input>> augmentation = Collections.emptyMap();
    
        InputImpl(InputBuilder base) {
            this._resetAt = base.getResetAt();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<Input> getImplementedInterface() {
            return Input.class;
        }
    
        @Override
        public String getResetAt() {
            return _resetAt;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<Input>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_resetAt);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!Input.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            Input other = (Input)obj;
            if (!Objects.equals(_resetAt, other.getResetAt())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                InputImpl otherImpl = (InputImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<Input>>, Augmentation<Input>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("Input");
            CodeHelpers.appendValue(helper, "_resetAt", _resetAt);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> example-data-center-10.2.1-sources.jar: org/opendaylight/yang/gen/v1/urn/example/data/center/rev180807/server/reset/InputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.example.data.center.rev180807.server.reset;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link InputBuilder} instances.
 *
 * @see InputBuilder
 *
 */
public class InputBuilder implements Builder<Input> {

    private String _resetAt;


    Map<Class<? extends Augmentation<Input>>, Augmentation<Input>> augmentation = Collections.emptyMap();

    public InputBuilder() {
    }

    public InputBuilder(Input base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<Input>>, Augmentation<Input>> aug =((AugmentationHolder<Input>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._resetAt = base.getResetAt();
    }


    public String getResetAt() {
        return _resetAt;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Input>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public InputBuilder setResetAt(final String value) {
        this._resetAt = value;
        return this;
    }
    
    public InputBuilder addAugmentation(Class<? extends Augmentation<Input>> augmentationType, Augmentation<Input> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public InputBuilder removeAugmentation(Class<? extends Augmentation<Input>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Input build() {
        return new InputImpl(this);
    }

    private static final class InputImpl
        extends AbstractAugmentable<Input>
        implements Input {
    
        private final String _resetAt;
    
        InputImpl(InputBuilder base) {
            super(base.augmentation);
            this._resetAt = base.getResetAt();
        }
    
        @Override
        public Class<Input> getImplementedInterface() {
            return Input.class;
        }
    
        @Override
        public String getResetAt() {
            return _resetAt;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_resetAt);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!Input.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            Input other = (Input)obj;
            if (!Objects.equals(_resetAt, other.getResetAt())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                InputImpl otherImpl = (InputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<Input>>, Augmentation<Input>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("Input");
            CodeHelpers.appendValue(helper, "_resetAt", _resetAt);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
